@@ -1,17 +1,7 @@
 /*
- *
- * Copyright (C) 2003-2009 Sebastian Trueg <trueg@k3b.org>
- *
- * This file is part of the K3b project.
- * Copyright (C) 1998-2009 Sebastian Trueg <trueg@k3b.org>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- * See the file "COPYING" for the exact licensing terms.
- */
-
+    SPDX-FileCopyrightText: 1998-2009 Sebastian Trueg <trueg@k3b.org>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "k3bdatajob.h"
 #include "k3bdatadoc.h"
@@ -699,13 +689,12 @@ bool K3b::DataJob::waitForBurnMedium()
 {
     // start with all media types supported by the writer
     Device::MediaTypes m  = d->doc->supportedMediaTypes() & d->doc->burner()->writeCapabilities();
-
     // if everything goes wrong we are left with no possible media to request
     if ( !m ) {
         emit infoMessage( i18n( "Internal Error: No medium type fits. This project cannot be burned." ), MessageError );
         return false;
     }
-
+    const K3b::ExternalBin* cdrecordBin = k3bcore->externalBinManager()->binObject("cdrecord");
     emit newSubTask( i18n("Waiting for a medium") );
     Device::MediaType foundMedium = waitForMedium( d->doc->burner(),
                                                    usedMultiSessionMode() == K3b::DataDoc::CONTINUE ||
@@ -751,7 +740,7 @@ bool K3b::DataJob::waitForBurnMedium()
 
                     qDebug() << "(K3b::DataJob) using datamode: "
                              << (d->usedDataMode == K3b::DataMode1 ? "mode1" : "mode2")
-                             << endl;
+                             << Qt::endl;
                 }
             }
             else if( usedMultiSessionMode() == K3b::DataDoc::NONE )
@@ -812,7 +801,7 @@ bool K3b::DataJob::waitForBurnMedium()
         // let's default to cdrecord for the time being (except for special cases below)
         // but prefer growisofs for DVDs
         if ( d->usedWritingApp == K3b::WritingAppAuto ) {
-            if (k3bcore->externalBinManager()->binObject("cdrecord")->hasFeature( "wodim" ))
+            if (cdrecordBin && cdrecordBin->hasFeature( "wodim" ))
                 d->usedWritingApp = K3b::WritingAppGrowisofs;
             else
                 d->usedWritingApp = K3b::WritingAppCdrecord;
@@ -931,15 +920,14 @@ bool K3b::DataJob::waitForBurnMedium()
     else if ( foundMedium & K3b::Device::MEDIA_BD_ALL ) {
         d->usedWritingApp = writingApp();
         if( d->usedWritingApp == K3b::WritingAppAuto ) {
-            if (k3bcore->externalBinManager()->binObject("cdrecord")->hasFeature( "wodim" ))
+            if ( cdrecordBin && cdrecordBin->hasFeature( "wodim" ))
                 d->usedWritingApp = K3b::WritingAppGrowisofs;
             else
                 d->usedWritingApp = K3b::WritingAppCdrecord;
         }
 
         if (d->usedWritingApp == K3b::WritingAppCdrecord &&
-            k3bcore->externalBinManager()->binObject("cdrecord") &&
-            !k3bcore->externalBinManager()->binObject("cdrecord")->hasFeature("blu-ray")) {
+            cdrecordBin && !cdrecordBin->hasFeature("blu-ray")) {
             d->usedWritingApp = K3b::WritingAppGrowisofs;
         }
 
@@ -1075,8 +1063,8 @@ bool K3b::DataJob::setupCdrecordJob()
     if( d->usedDataMode == K3b::DataMode1 )
         writer->addArgument( "-data" );
     else {
-        if( k3bcore->externalBinManager()->binObject("cdrecord") &&
-            k3bcore->externalBinManager()->binObject("cdrecord")->hasFeature( "xamix" ) )
+        const K3b::ExternalBin* cdrecordBin = k3bcore->externalBinManager()->binObject("cdrecord");
+        if( cdrecordBin && cdrecordBin->hasFeature( "xamix" ) )
             writer->addArgument( "-xa" );
         else
             writer->addArgument( "-xa1" );
